==> jc-1.4.0.tar.gz: javax/swing/ToolTipManager__24insideTimerAction.h <==
// public class javax.swing.ToolTipManager$insideTimerAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5a1171e453894e8 javax_swing_ToolTipManager__24insideTimerAction

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_ToolTipManager__24insideTimerAction_H_
#define _JC_javax_swing_ToolTipManager__24insideTimerAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_ToolTipManager$object;

// Typedefs
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_refs	_jc_javax_swing_ToolTipManager__24insideTimerAction$sub_refs;
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_nonrefs	_jc_javax_swing_ToolTipManager__24insideTimerAction$sub_nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$refs	_jc_javax_swing_ToolTipManager__24insideTimerAction$refs;
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$nonrefs	_jc_javax_swing_ToolTipManager__24insideTimerAction$nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object	_jc_javax_swing_ToolTipManager__24insideTimerAction$object;

typedef const struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vmethods	_jc_javax_swing_ToolTipManager__24insideTimerAction$vmethods;
typedef const struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vtable	_jc_javax_swing_ToolTipManager__24insideTimerAction$vtable;
typedef const struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vtype	_jc_javax_swing_ToolTipManager__24insideTimerAction$vtype;

// Constructors
extern void _jc_javax_swing_ToolTipManager__24insideTimerAction$method$_init$4f7171db22e499d9(_jc_env *, struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object *, struct _jc_javax_swing_ToolTipManager$object *);

// Virtual methods
extern void _jc_javax_swing_ToolTipManager__24insideTimerAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ToolTipManager__24insideTimerAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ToolTipManager__24insideTimerAction$vmethods	javax_swing_ToolTipManager__24insideTimerAction;
};

// Vtype
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vtype {
	_jc_type			type;
	_jc_javax_swing_ToolTipManager__24insideTimerAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_refs {
	struct _jc_javax_swing_ToolTipManager$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$refs {
    _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_refs	javax_swing_ToolTipManager__24insideTimerAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_nonrefs	javax_swing_ToolTipManager__24insideTimerAction;
};

// Object instance structure
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object {
	_jc_javax_swing_ToolTipManager__24insideTimerAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ToolTipManager__24insideTimerAction$vtype	*vtype;
	_jc_javax_swing_ToolTipManager__24insideTimerAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ToolTipManager__24insideTimerAction$vtype _jc_javax_swing_ToolTipManager__24insideTimerAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ToolTipManager__24insideTimerAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ToolTipManager__24insideTimerAction$class_object;

#endif	/* _JC_javax_swing_ToolTipManager__24insideTimerAction_H_ */

==> jc-1.4.6.tar.gz: javax/swing/ToolTipManager__24insideTimerAction.h <==
// public class javax.swing.ToolTipManager$insideTimerAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c503a8310c71cf2a javax_swing_ToolTipManager__24insideTimerAction

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_ToolTipManager__24insideTimerAction_H_
#define _JC_javax_swing_ToolTipManager__24insideTimerAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_ToolTipManager$object;

// Typedefs
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_refs	_jc_javax_swing_ToolTipManager__24insideTimerAction$sub_refs;
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_nonrefs	_jc_javax_swing_ToolTipManager__24insideTimerAction$sub_nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$refs	_jc_javax_swing_ToolTipManager__24insideTimerAction$refs;
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$nonrefs	_jc_javax_swing_ToolTipManager__24insideTimerAction$nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object	_jc_javax_swing_ToolTipManager__24insideTimerAction$object;

typedef const struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vmethods	_jc_javax_swing_ToolTipManager__24insideTimerAction$vmethods;
typedef const struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vtable	_jc_javax_swing_ToolTipManager__24insideTimerAction$vtable;
typedef const struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vtype	_jc_javax_swing_ToolTipManager__24insideTimerAction$vtype;

// Constructors
extern void _jc_javax_swing_ToolTipManager__24insideTimerAction$method$_init$4f7171db22e499d9(_jc_env *, struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object *, struct _jc_javax_swing_ToolTipManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_ToolTipManager__24insideTimerAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ToolTipManager__24insideTimerAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ToolTipManager__24insideTimerAction$vmethods	javax_swing_ToolTipManager__24insideTimerAction;
};

// Vtype
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$vtype {
	_jc_type			type;
	_jc_javax_swing_ToolTipManager__24insideTimerAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_refs {
	struct _jc_javax_swing_ToolTipManager$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$refs {
    _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_refs	javax_swing_ToolTipManager__24insideTimerAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ToolTipManager__24insideTimerAction$sub_nonrefs	javax_swing_ToolTipManager__24insideTimerAction;
};

// Object instance structure
struct _jc_javax_swing_ToolTipManager__24insideTimerAction$object {
	_jc_javax_swing_ToolTipManager__24insideTimerAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ToolTipManager__24insideTimerAction$vtype	*vtype;
	_jc_javax_swing_ToolTipManager__24insideTimerAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ToolTipManager__24insideTimerAction$vtype _jc_javax_swing_ToolTipManager__24insideTimerAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ToolTipManager__24insideTimerAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ToolTipManager__24insideTimerAction$class_object;

#endif	/* _JC_javax_swing_ToolTipManager__24insideTimerAction_H_ */
